summaryrefslogtreecommitdiff
path: root/gpsd.h
diff options
context:
space:
mode:
authorGary E. Miller <gem@rellim.com>2019-04-12 20:06:43 -0700
committerGary E. Miller <gem@rellim.com>2019-04-12 20:06:43 -0700
commit393a3a02c84146b39a76ceaf48ed112625f87ff7 (patch)
tree9da879ad6a76721752ed2870f66bcac5a01d2672 /gpsd.h
parent59d0330b70e0364b7ffb1bc37df8b341cdda75e5 (diff)
downloadgpsd-393a3a02c84146b39a76ceaf48ed112625f87ff7.tar.gz
ubxtool: Add end of cycle detection.
This made the ublox-neo-m8n.log regression finally look good. Needed for u-blox 9.
Diffstat (limited to 'gpsd.h')
-rw-r--r--gpsd.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/gpsd.h b/gpsd.h
index 8f3c12b8..fcff9f6c 100644
--- a/gpsd.h
+++ b/gpsd.h
@@ -58,7 +58,7 @@ extern "C" {
* Add cfg_stage and cfg_step, for initialization
* Add oldfix2 for better oldfix
* Make subtype longer
- * Add ubx.protver, ubx.end_class, ubx.end_id to gps_device_t
+ * Add ubx.protver, ubx.end_class and more to gps_device_t.ubx
*/
/* Keep in sync with api_major_version and api_minor gps/__init__.py */
#define GPSD_PROTO_MAJOR_VERSION 3 /* bump on incompatible changes */
@@ -701,8 +701,8 @@ struct gps_device_t {
unsigned char port_id;
unsigned char sbas_in_use;
unsigned char protver; /* u-blox protocol version */
- unsigned char end_class; /* cycle ender class */
- unsigned char end_id; /* cycle ender ID */
+ unsigned char last_msgid; /* last class/ID */
+ unsigned char end_msgid; /* cycle ender class/ID */
} ubx;
#endif /* UBLOX_ENABLE */
#ifdef NAVCOM_ENABLE